function op = haversine(pt1, pt2)
    % from https://www.movable-type.co.uk/scripts/latlong.html
    % a = sin²(Δφ/2) + cos φ1 ⋅ cos φ2 ⋅ sin²(Δλ/2)
    % c = 2 ⋅ atan2( √a, √(1−a) )
    % d = R ⋅ c
    %  where	φ is latitude, λ is longitude, R is earth%s radius
    %(mean radius = 6,371km); note that angles need to be in radians
    % to pass to trig functions!
    %
    R = 6371;  % km
    phi1 = deg2rad(pt1(1));
    phi2 = deg2rad(pt2(:,1));
    delta_phi = phi2 - phi1;
    delta_lambda = deg2rad(pt2(:, 2) - pt1(2));
    a = sin(delta_phi ./ 2).^2 + (cos(phi1) .* cos(phi2) .* (sin(delta_lambda ./ 2).^2));
    c = 2 .* atan2(sqrt(a), sqrt(1 - a));
    op = R * c;  % km
end